FastIterPrint

Trait FastIterPrint 

pub trait FastIterPrint {
    // Required method
    fn fast_iter_print<W: Write, S: FastPrint>(
        self,
        writer: &mut FastOutput<W>,
        sep: S,
        is_head: bool,
    );
}

Required Methods

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FastIterPrint for ()

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, _writer: &mut FastOutput<W>, _sep: S, _is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint, G: FastPrint, H: FastPrint, I: FastPrint, J: FastPrint, K: FastPrint> FastIterPrint for (A, B, C, D, E, F, G, H, I, J, K)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint, G: FastPrint, H: FastPrint, I: FastPrint, J: FastPrint> FastIterPrint for (A, B, C, D, E, F, G, H, I, J)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint, G: FastPrint, H: FastPrint, I: FastPrint> FastIterPrint for (A, B, C, D, E, F, G, H, I)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint, G: FastPrint, H: FastPrint> FastIterPrint for (A, B, C, D, E, F, G, H)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint, G: FastPrint> FastIterPrint for (A, B, C, D, E, F, G)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint, F: FastPrint> FastIterPrint for (A, B, C, D, E, F)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint, E: FastPrint> FastIterPrint for (A, B, C, D, E)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint, D: FastPrint> FastIterPrint for (A, B, C, D)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint, C: FastPrint> FastIterPrint for (A, B, C)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint, B: FastPrint> FastIterPrint for (A, B)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Source

impl<A: FastPrint> FastIterPrint for (A,)

Source

fn fast_iter_print<W: Write, S: FastPrint>( self, writer: &mut FastOutput<W>, sep: S, is_head: bool, )

Implementors